@@ -578,7 +578,8 @@ class VariableOsClockTimezone(ReadonlyVariable):
             return timezone
         # get timezone from /etc/timezone
         if path.exists(timezonefile):
-            return open(timezonefile, "r").read().strip()
+            with open(timezonefile, "r") as f:
+                return f.read().strip()
         return "UTC"
 
 
